@@ -365,7 +365,7 @@ static void run_playback ()
             break;
 
         // rewind file pointer before repeating
-        if (file.fseek (0, VFS_SEEK_SET) != 0)
+        if (file && file.fseek (0, VFS_SEEK_SET) != 0)
         {
             pb_info.error = true;
             break;
@@ -661,24 +661,6 @@ EXPORT bool aud_drct_get_paused ()
     return paused;
 }
 
-// thread-safe
-EXPORT int aud_drct_get_position ()
-{
-    lock ();
-    int entry = is_ready () ? pb_info.entry : -1;
-    unlock ();
-    return entry;
-}
-
-// thread-safe
-EXPORT String aud_drct_get_filename ()
-{
-    lock ();
-    String filename = is_ready () ? pb_info.filename : String ();
-    unlock ();
-    return filename;
-}
-
 // thread-safe
 EXPORT String aud_drct_get_title ()
 {
